@@ -22,25 +22,25 @@ $Data::Dumper::Sortkeys = 1;
 
 =head1 NAME
 
-Lavoco::Web::Editor - Experimental framework with two constraints: FastCGI and Template::Toolkit to edit flat files.
+Lavoco::Web::Editor - FastCGI app to edit flat-files.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 $VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
 
-Framework to run small web app to edit flat files, running as a FastCGI application.
+This application was originally designed to aid in the editing of basic templates for a L<Lavoco::Web::App> project.
 
  use Lavoco::Web::Editor;
  
- my $editor = Lavoco::Web::Editor->new( name => 'Example editor' );
+ my $editor = Lavoco::Web::Editor->new;
  
  my $action = lc( $ARGV[0] );   # (start|stop|restart)
  
@@ -54,13 +54,12 @@ Framework to run small web app to edit flat files, running as a FastCGI applicat
 
 =head3 new
 
-Creates a new instance of the web-app editor object.
+Creates a new instance of the editor object.
 
 =head2 Attributes
 
 =cut
 
-has  name      => ( is => 'rw', isa => 'Str',  default => 'App' );
 has  processes => ( is => 'rw', isa => 'Int',  default => 5         );
 has  base      => ( is => 'rw', isa => 'Str',  lazy => 1, builder => '_build_base'      );
 has _pid       => ( is => 'rw', isa => 'Str',  lazy => 1, builder => '_build__pid'      );
@@ -94,13 +93,9 @@ sub _build_filename
     return $self->base . '/editor.json';
 }
 
-=head3 name
-
-The identifier for the web-app, used as the FastCGI-process title.
-
 =head3 base
 
-The base directory of the application, detected using L<FindBin>.
+The base directory of the application, using L<FindBin>.
 
 =head3 processes
 
@@ -112,13 +107,13 @@ Filename for the config file, default is C<editor.json> and only JSON is current
 
 =head3 config
 
-The config as a hash-reference.
+The loaded config as a hash-reference.
 
 =head2 Instance Methods
 
 =head3 start
 
-Starts the FastCGI daemon.  Performs basic checks of your environment and dies if there's a problem.
+Starts the FastCGI daemon.  Performs basic checks of your environment and config, dies if there's a problem.
 
 =cut
 
@@ -142,7 +137,6 @@ sub start
         listen     => [ $self->_socket ],
         pid        =>   $self->_pid,
         detach     =>   1,
-        proc_title =>   $self->name,
     );
     
     $server->run( $self->_handler );
@@ -317,15 +311,13 @@ The editor app should be a simple Perl script in a folder with the following str
  editor.sock    # generated, to accept incoming FastCGI connections
  logs/
  
-The config file is read for each and every request, this makes adding new pages easy, without the need to restart the application - you can edit its own config file.
+The config file is read for each and every request, so you can reasonably enable editing of the editors own config file.
 
 The config file should be placed in the C<base> directory of your editor application.
 
-See the C<examples> directory for a sample JSON config file, something like the following...
+See the C<examples> directory for a sample JSON config file, similar to the following...
 
  {
-     "password" : "foo",
-     "salt"     : "abc123",
      "folders"  : [
          "templates/content/organic",
          "templates/content/store"
@@ -333,16 +325,20 @@ See the C<examples> directory for a sample JSON config file, something like the
      "files"    : [
          "app.json",
          "site/style.css"
-     ]
+     ],
+     "password" : "foo",
+     "salt"     : "abc123"
  }
 
 Two fields which drive the editor are C<folders> and C<files>, each of which is an array of paths, all relative to C<$editor-E<gt>base>.
 
-Files in the folders are all editable, but not sub-directories, you need to add those separately.
+All visible files in the C<folders> are editable, but not sub-directories, you need to add those separately.  The editor can also create new files in each folder.
 
-If the field for C<password> exists in the config, then this will be requested before a user can access the index page (listing all files that can be edited).
+Files in the C<files> list are editable, but the editor can not create new files in their respective containing directories.
 
-When using a C<password>, a C<salt> is also required, just create a random string, it's concatenated to the password before SHA-hashing and setting as a cookie.
+If there is a defined C<password> in the config, then this will be requested before a user can access the index page (listing all files that can be edited).
+
+When using a C<password>, a C<salt> is also required, just create a random string, it's simply concatenated to the password before SHA-hashing and setting as a cookie.
 
 =cut
 
@@ -729,7 +725,7 @@ Rob Brown, C<< <rob at intelcompute.com> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2014 Rob Brown.
+Copyright 2015 Rob Brown.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
